from typing import Literal

BorderColor = Literal[
    'inherit',
    'current',
    'transparent',
    'black',
    'white',
    'slate-50',
    'slate-100',
    'slate-200',
    'slate-300',
    'slate-400',
    'slate-500',
    'slate-600',
    'slate-700',
    'slate-800',
    'slate-900',
    'slate-950',
    'gray-50',
    'gray-100',
    'gray-200',
    'gray-300',
    'gray-400',
    'gray-500',
    'gray-600',
    'gray-700',
    'gray-800',
    'gray-900',
    'gray-950',
    'zinc-50',
    'zinc-100',
    'zinc-200',
    'zinc-300',
    'zinc-400',
    'zinc-500',
    'zinc-600',
    'zinc-700',
    'zinc-800',
    'zinc-900',
    'zinc-950',
    'neutral-50',
    'neutral-100',
    'neutral-200',
    'neutral-300',
    'neutral-400',
    'neutral-500',
    'neutral-600',
    'neutral-700',
    'neutral-800',
    'neutral-900',
    'neutral-950',
    'stone-50',
    'stone-100',
    'stone-200',
    'stone-300',
    'stone-400',
    'stone-500',
    'stone-600',
    'stone-700',
    'stone-800',
    'stone-900',
    'stone-950',
    'red-50',
    'red-100',
    'red-200',
    'red-300',
    'red-400',
    'red-500',
    'red-600',
    'red-700',
    'red-800',
    'red-900',
    'red-950',
    'orange-50',
    'orange-100',
    'orange-200',
    'orange-300',
    'orange-400',
    'orange-500',
    'orange-600',
    'orange-700',
    'orange-800',
    'orange-900',
    'orange-950',
    'amber-50',
    'amber-100',
    'amber-200',
    'amber-300',
    'amber-400',
    'amber-500',
    'amber-600',
    'amber-700',
    'amber-800',
    'amber-900',
    'amber-950',
    'yellow-50',
    'yellow-100',
    'yellow-200',
    'yellow-300',
    'yellow-400',
    'yellow-500',
    'yellow-600',
    'yellow-700',
    'yellow-800',
    'yellow-900',
    'yellow-950',
    'lime-50',
    'lime-100',
    'lime-200',
    'lime-300',
    'lime-400',
    'lime-500',
    'lime-600',
    'lime-700',
    'lime-800',
    'lime-900',
    'lime-950',
    'green-50',
    'green-100',
    'green-200',
    'green-300',
    'green-400',
    'green-500',
    'green-600',
    'green-700',
    'green-800',
    'green-900',
    'green-950',
    'emerald-50',
    'emerald-100',
    'emerald-200',
    'emerald-300',
    'emerald-400',
    'emerald-500',
    'emerald-600',
    'emerald-700',
    'emerald-800',
    'emerald-900',
    'emerald-950',
    'teal-50',
    'teal-100',
    'teal-200',
    'teal-300',
    'teal-400',
    'teal-500',
    'teal-600',
    'teal-700',
    'teal-800',
    'teal-900',
    'teal-950',
    'cyan-50',
    'cyan-100',
    'cyan-200',
    'cyan-300',
    'cyan-400',
    'cyan-500',
    'cyan-600',
    'cyan-700',
    'cyan-800',
    'cyan-900',
    'cyan-950',
    'sky-50',
    'sky-100',
    'sky-200',
    'sky-300',
    'sky-400',
    'sky-500',
    'sky-600',
    'sky-700',
    'sky-800',
    'sky-900',
    'sky-950',
    'blue-50',
    'blue-100',
    'blue-200',
    'blue-300',
    'blue-400',
    'blue-500',
    'blue-600',
    'blue-700',
    'blue-800',
    'blue-900',
    'blue-950',
    'indigo-50',
    'indigo-100',
    'indigo-200',
    'indigo-300',
    'indigo-400',
    'indigo-500',
    'indigo-600',
    'indigo-700',
    'indigo-800',
    'indigo-900',
    'indigo-950',
    'violet-50',
    'violet-100',
    'violet-200',
    'violet-300',
    'violet-400',
    'violet-500',
    'violet-600',
    'violet-700',
    'violet-800',
    'violet-900',
    'violet-950',
    'purple-50',
    'purple-100',
    'purple-200',
    'purple-300',
    'purple-400',
    'purple-500',
    'purple-600',
    'purple-700',
    'purple-800',
    'purple-900',
    'purple-950',
    'fuchsia-50',
    'fuchsia-100',
    'fuchsia-200',
    'fuchsia-300',
    'fuchsia-400',
    'fuchsia-500',
    'fuchsia-600',
    'fuchsia-700',
    'fuchsia-800',
    'fuchsia-900',
    'fuchsia-950',
    'pink-50',
    'pink-100',
    'pink-200',
    'pink-300',
    'pink-400',
    'pink-500',
    'pink-600',
    'pink-700',
    'pink-800',
    'pink-900',
    'pink-950',
    'rose-50',
    'rose-100',
    'rose-200',
    'rose-300',
    'rose-400',
    'rose-500',
    'rose-600',
    'rose-700',
    'rose-800',
    'rose-900',
    'rose-950',
    'x-inherit',
    'x-current',
    'x-transparent',
    'x-black',
    'x-white',
    'x-slate-50',
    'x-slate-100',
    'x-slate-200',
    'x-slate-300',
    'x-slate-400',
    'x-slate-500',
    'x-slate-600',
    'x-slate-700',
    'x-slate-800',
    'x-slate-900',
    'x-slate-950',
    'x-gray-50',
    'x-gray-100',
    'x-gray-200',
    'x-gray-300',
    'x-gray-400',
    'x-gray-500',
    'x-gray-600',
    'x-gray-700',
    'x-gray-800',
    'x-gray-900',
    'x-gray-950',
    'x-zinc-50',
    'x-zinc-100',
    'x-zinc-200',
    'x-zinc-300',
    'x-zinc-400',
    'x-zinc-500',
    'x-zinc-600',
    'x-zinc-700',
    'x-zinc-800',
    'x-zinc-900',
    'x-zinc-950',
    'x-neutral-50',
    'x-neutral-100',
    'x-neutral-200',
    'x-neutral-300',
    'x-neutral-400',
    'x-neutral-500',
    'x-neutral-600',
    'x-neutral-700',
    'x-neutral-800',
    'x-neutral-900',
    'x-neutral-950',
    'x-stone-50',
    'x-stone-100',
    'x-stone-200',
    'x-stone-300',
    'x-stone-400',
    'x-stone-500',
    'x-stone-600',
    'x-stone-700',
    'x-stone-800',
    'x-stone-900',
    'x-stone-950',
    'x-red-50',
    'x-red-100',
    'x-red-200',
    'x-red-300',
    'x-red-400',
    'x-red-500',
    'x-red-600',
    'x-red-700',
    'x-red-800',
    'x-red-900',
    'x-red-950',
    'x-orange-50',
    'x-orange-100',
    'x-orange-200',
    'x-orange-300',
    'x-orange-400',
    'x-orange-500',
    'x-orange-600',
    'x-orange-700',
    'x-orange-800',
    'x-orange-900',
    'x-orange-950',
    'x-amber-50',
    'x-amber-100',
    'x-amber-200',
    'x-amber-300',
    'x-amber-400',
    'x-amber-500',
    'x-amber-600',
    'x-amber-700',
    'x-amber-800',
    'x-amber-900',
    'x-amber-950',
    'x-yellow-50',
    'x-yellow-100',
    'x-yellow-200',
    'x-yellow-300',
    'x-yellow-400',
    'x-yellow-500',
    'x-yellow-600',
    'x-yellow-700',
    'x-yellow-800',
    'x-yellow-900',
    'x-yellow-950',
    'x-lime-50',
    'x-lime-100',
    'x-lime-200',
    'x-lime-300',
    'x-lime-400',
    'x-lime-500',
    'x-lime-600',
    'x-lime-700',
    'x-lime-800',
    'x-lime-900',
    'x-lime-950',
    'x-green-50',
    'x-green-100',
    'x-green-200',
    'x-green-300',
    'x-green-400',
    'x-green-500',
    'x-green-600',
    'x-green-700',
    'x-green-800',
    'x-green-900',
    'x-green-950',
    'x-emerald-50',
    'x-emerald-100',
    'x-emerald-200',
    'x-emerald-300',
    'x-emerald-400',
    'x-emerald-500',
    'x-emerald-600',
    'x-emerald-700',
    'x-emerald-800',
    'x-emerald-900',
    'x-emerald-950',
    'x-teal-50',
    'x-teal-100',
    'x-teal-200',
    'x-teal-300',
    'x-teal-400',
    'x-teal-500',
    'x-teal-600',
    'x-teal-700',
    'x-teal-800',
    'x-teal-900',
    'x-teal-950',
    'x-cyan-50',
    'x-cyan-100',
    'x-cyan-200',
    'x-cyan-300',
    'x-cyan-400',
    'x-cyan-500',
    'x-cyan-600',
    'x-cyan-700',
    'x-cyan-800',
    'x-cyan-900',
    'x-cyan-950',
    'x-sky-50',
    'x-sky-100',
    'x-sky-200',
    'x-sky-300',
    'x-sky-400',
    'x-sky-500',
    'x-sky-600',
    'x-sky-700',
    'x-sky-800',
    'x-sky-900',
    'x-sky-950',
    'x-blue-50',
    'x-blue-100',
    'x-blue-200',
    'x-blue-300',
    'x-blue-400',
    'x-blue-500',
    'x-blue-600',
    'x-blue-700',
    'x-blue-800',
    'x-blue-900',
    'x-blue-950',
    'x-indigo-50',
    'x-indigo-100',
    'x-indigo-200',
    'x-indigo-300',
    'x-indigo-400',
    'x-indigo-500',
    'x-indigo-600',
    'x-indigo-700',
    'x-indigo-800',
    'x-indigo-900',
    'x-indigo-950',
    'x-violet-50',
    'x-violet-100',
    'x-violet-200',
    'x-violet-300',
    'x-violet-400',
    'x-violet-500',
    'x-violet-600',
    'x-violet-700',
    'x-violet-800',
    'x-violet-900',
    'x-violet-950',
    'x-purple-50',
    'x-purple-100',
    'x-purple-200',
    'x-purple-300',
    'x-purple-400',
    'x-purple-500',
    'x-purple-600',
    'x-purple-700',
    'x-purple-800',
    'x-purple-900',
    'x-purple-950',
    'x-fuchsia-50',
    'x-fuchsia-100',
    'x-fuchsia-200',
    'x-fuchsia-300',
    'x-fuchsia-400',
    'x-fuchsia-500',
    'x-fuchsia-600',
    'x-fuchsia-700',
    'x-fuchsia-800',
    'x-fuchsia-900',
    'x-fuchsia-950',
    'x-pink-50',
    'x-pink-100',
    'x-pink-200',
    'x-pink-300',
    'x-pink-400',
    'x-pink-500',
    'x-pink-600',
    'x-pink-700',
    'x-pink-800',
    'x-pink-900',
    'x-pink-950',
    'x-rose-50',
    'x-rose-100',
    'x-rose-200',
    'x-rose-300',
    'x-rose-400',
    'x-rose-500',
    'x-rose-600',
    'x-rose-700',
    'x-rose-800',
    'x-rose-900',
    'x-rose-950',
    'y-inherit',
    'y-current',
    'y-transparent',
    'y-black',
    'y-white',
    'y-slate-50',
    'y-slate-100',
    'y-slate-200',
    'y-slate-300',
    'y-slate-400',
    'y-slate-500',
    'y-slate-600',
    'y-slate-700',
    'y-slate-800',
    'y-slate-900',
    'y-slate-950',
    'y-gray-50',
    'y-gray-100',
    'y-gray-200',
    'y-gray-300',
    'y-gray-400',
    'y-gray-500',
    'y-gray-600',
    'y-gray-700',
    'y-gray-800',
    'y-gray-900',
    'y-gray-950',
    'y-zinc-50',
    'y-zinc-100',
    'y-zinc-200',
    'y-zinc-300',
    'y-zinc-400',
    'y-zinc-500',
    'y-zinc-600',
    'y-zinc-700',
    'y-zinc-800',
    'y-zinc-900',
    'y-zinc-950',
    'y-neutral-50',
    'y-neutral-100',
    'y-neutral-200',
    'y-neutral-300',
    'y-neutral-400',
    'y-neutral-500',
    'y-neutral-600',
    'y-neutral-700',
    'y-neutral-800',
    'y-neutral-900',
    'y-neutral-950',
    'y-stone-50',
    'y-stone-100',
    'y-stone-200',
    'y-stone-300',
    'y-stone-400',
    'y-stone-500',
    'y-stone-600',
    'y-stone-700',
    'y-stone-800',
    'y-stone-900',
    'y-stone-950',
    'y-red-50',
    'y-red-100',
    'y-red-200',
    'y-red-300',
    'y-red-400',
    'y-red-500',
    'y-red-600',
    'y-red-700',
    'y-red-800',
    'y-red-900',
    'y-red-950',
    'y-orange-50',
    'y-orange-100',
    'y-orange-200',
    'y-orange-300',
    'y-orange-400',
    'y-orange-500',
    'y-orange-600',
    'y-orange-700',
    'y-orange-800',
    'y-orange-900',
    'y-orange-950',
    'y-amber-50',
    'y-amber-100',
    'y-amber-200',
    'y-amber-300',
    'y-amber-400',
    'y-amber-500',
    'y-amber-600',
    'y-amber-700',
    'y-amber-800',
    'y-amber-900',
    'y-amber-950',
    'y-yellow-50',
    'y-yellow-100',
    'y-yellow-200',
    'y-yellow-300',
    'y-yellow-400',
    'y-yellow-500',
    'y-yellow-600',
    'y-yellow-700',
    'y-yellow-800',
    'y-yellow-900',
    'y-yellow-950',
    'y-lime-50',
    'y-lime-100',
    'y-lime-200',
    'y-lime-300',
    'y-lime-400',
    'y-lime-500',
    'y-lime-600',
    'y-lime-700',
    'y-lime-800',
    'y-lime-900',
    'y-lime-950',
    'y-green-50',
    'y-green-100',
    'y-green-200',
    'y-green-300',
    'y-green-400',
    'y-green-500',
    'y-green-600',
    'y-green-700',
    'y-green-800',
    'y-green-900',
    'y-green-950',
    'y-emerald-50',
    'y-emerald-100',
    'y-emerald-200',
    'y-emerald-300',
    'y-emerald-400',
    'y-emerald-500',
    'y-emerald-600',
    'y-emerald-700',
    'y-emerald-800',
    'y-emerald-900',
    'y-emerald-950',
    'y-teal-50',
    'y-teal-100',
    'y-teal-200',
    'y-teal-300',
    'y-teal-400',
    'y-teal-500',
    'y-teal-600',
    'y-teal-700',
    'y-teal-800',
    'y-teal-900',
    'y-teal-950',
    'y-cyan-50',
    'y-cyan-100',
    'y-cyan-200',
    'y-cyan-300',
    'y-cyan-400',
    'y-cyan-500',
    'y-cyan-600',
    'y-cyan-700',
    'y-cyan-800',
    'y-cyan-900',
    'y-cyan-950',
    'y-sky-50',
    'y-sky-100',
    'y-sky-200',
    'y-sky-300',
    'y-sky-400',
    'y-sky-500',
    'y-sky-600',
    'y-sky-700',
    'y-sky-800',
    'y-sky-900',
    'y-sky-950',
    'y-blue-50',
    'y-blue-100',
    'y-blue-200',
    'y-blue-300',
    'y-blue-400',
    'y-blue-500',
    'y-blue-600',
    'y-blue-700',
    'y-blue-800',
    'y-blue-900',
    'y-blue-950',
    'y-indigo-50',
    'y-indigo-100',
    'y-indigo-200',
    'y-indigo-300',
    'y-indigo-400',
    'y-indigo-500',
    'y-indigo-600',
    'y-indigo-700',
    'y-indigo-800',
    'y-indigo-900',
    'y-indigo-950',
    'y-violet-50',
    'y-violet-100',
    'y-violet-200',
    'y-violet-300',
    'y-violet-400',
    'y-violet-500',
    'y-violet-600',
    'y-violet-700',
    'y-violet-800',
    'y-violet-900',
    'y-violet-950',
    'y-purple-50',
    'y-purple-100',
    'y-purple-200',
    'y-purple-300',
    'y-purple-400',
    'y-purple-500',
    'y-purple-600',
    'y-purple-700',
    'y-purple-800',
    'y-purple-900',
    'y-purple-950',
    'y-fuchsia-50',
    'y-fuchsia-100',
    'y-fuchsia-200',
    'y-fuchsia-300',
    'y-fuchsia-400',
    'y-fuchsia-500',
    'y-fuchsia-600',
    'y-fuchsia-700',
    'y-fuchsia-800',
    'y-fuchsia-900',
    'y-fuchsia-950',
    'y-pink-50',
    'y-pink-100',
    'y-pink-200',
    'y-pink-300',
    'y-pink-400',
    'y-pink-500',
    'y-pink-600',
    'y-pink-700',
    'y-pink-800',
    'y-pink-900',
    'y-pink-950',
    'y-rose-50',
    'y-rose-100',
    'y-rose-200',
    'y-rose-300',
    'y-rose-400',
    'y-rose-500',
    'y-rose-600',
    'y-rose-700',
    'y-rose-800',
    'y-rose-900',
    'y-rose-950',
    's-inherit',
    's-current',
    's-transparent',
    's-black',
    's-white',
    's-slate-50',
    's-slate-100',
    's-slate-200',
    's-slate-300',
    's-slate-400',
    's-slate-500',
    's-slate-600',
    's-slate-700',
    's-slate-800',
    's-slate-900',
    's-slate-950',
    's-gray-50',
    's-gray-100',
    's-gray-200',
    's-gray-300',
    's-gray-400',
    's-gray-500',
    's-gray-600',
    's-gray-700',
    's-gray-800',
    's-gray-900',
    's-gray-950',
    's-zinc-50',
    's-zinc-100',
    's-zinc-200',
    's-zinc-300',
    's-zinc-400',
    's-zinc-500',
    's-zinc-600',
    's-zinc-700',
    's-zinc-800',
    's-zinc-900',
    's-zinc-950',
    's-neutral-50',
    's-neutral-100',
    's-neutral-200',
    's-neutral-300',
    's-neutral-400',
    's-neutral-500',
    's-neutral-600',
    's-neutral-700',
    's-neutral-800',
    's-neutral-900',
    's-neutral-950',
    's-stone-50',
    's-stone-100',
    's-stone-200',
    's-stone-300',
    's-stone-400',
    's-stone-500',
    's-stone-600',
    's-stone-700',
    's-stone-800',
    's-stone-900',
    's-stone-950',
    's-red-50',
    's-red-100',
    's-red-200',
    's-red-300',
    's-red-400',
    's-red-500',
    's-red-600',
    's-red-700',
    's-red-800',
    's-red-900',
    's-red-950',
    's-orange-50',
    's-orange-100',
    's-orange-200',
    's-orange-300',
    's-orange-400',
    's-orange-500',
    's-orange-600',
    's-orange-700',
    's-orange-800',
    's-orange-900',
    's-orange-950',
    's-amber-50',
    's-amber-100',
    's-amber-200',
    's-amber-300',
    's-amber-400',
    's-amber-500',
    's-amber-600',
    's-amber-700',
    's-amber-800',
    's-amber-900',
    's-amber-950',
    's-yellow-50',
    's-yellow-100',
    's-yellow-200',
    's-yellow-300',
    's-yellow-400',
    's-yellow-500',
    's-yellow-600',
    's-yellow-700',
    's-yellow-800',
    's-yellow-900',
    's-yellow-950',
    's-lime-50',
    's-lime-100',
    's-lime-200',
    's-lime-300',
    's-lime-400',
    's-lime-500',
    's-lime-600',
    's-lime-700',
    's-lime-800',
    's-lime-900',
    's-lime-950',
    's-green-50',
    's-green-100',
    's-green-200',
    's-green-300',
    's-green-400',
    's-green-500',
    's-green-600',
    's-green-700',
    's-green-800',
    's-green-900',
    's-green-950',
    's-emerald-50',
    's-emerald-100',
    's-emerald-200',
    's-emerald-300',
    's-emerald-400',
    's-emerald-500',
    's-emerald-600',
    's-emerald-700',
    's-emerald-800',
    's-emerald-900',
    's-emerald-950',
    's-teal-50',
    's-teal-100',
    's-teal-200',
    's-teal-300',
    's-teal-400',
    's-teal-500',
    's-teal-600',
    's-teal-700',
    's-teal-800',
    's-teal-900',
    's-teal-950',
    's-cyan-50',
    's-cyan-100',
    's-cyan-200',
    's-cyan-300',
    's-cyan-400',
    's-cyan-500',
    's-cyan-600',
    's-cyan-700',
    's-cyan-800',
    's-cyan-900',
    's-cyan-950',
    's-sky-50',
    's-sky-100',
    's-sky-200',
    's-sky-300',
    's-sky-400',
    's-sky-500',
    's-sky-600',
    's-sky-700',
    's-sky-800',
    's-sky-900',
    's-sky-950',
    's-blue-50',
    's-blue-100',
    's-blue-200',
    's-blue-300',
    's-blue-400',
    's-blue-500',
    's-blue-600',
    's-blue-700',
    's-blue-800',
    's-blue-900',
    's-blue-950',
    's-indigo-50',
    's-indigo-100',
    's-indigo-200',
    's-indigo-300',
    's-indigo-400',
    's-indigo-500',
    's-indigo-600',
    's-indigo-700',
    's-indigo-800',
    's-indigo-900',
    's-indigo-950',
    's-violet-50',
    's-violet-100',
    's-violet-200',
    's-violet-300',
    's-violet-400',
    's-violet-500',
    's-violet-600',
    's-violet-700',
    's-violet-800',
    's-violet-900',
    's-violet-950',
    's-purple-50',
    's-purple-100',
    's-purple-200',
    's-purple-300',
    's-purple-400',
    's-purple-500',
    's-purple-600',
    's-purple-700',
    's-purple-800',
    's-purple-900',
    's-purple-950',
    's-fuchsia-50',
    's-fuchsia-100',
    's-fuchsia-200',
    's-fuchsia-300',
    's-fuchsia-400',
    's-fuchsia-500',
    's-fuchsia-600',
    's-fuchsia-700',
    's-fuchsia-800',
    's-fuchsia-900',
    's-fuchsia-950',
    's-pink-50',
    's-pink-100',
    's-pink-200',
    's-pink-300',
    's-pink-400',
    's-pink-500',
    's-pink-600',
    's-pink-700',
    's-pink-800',
    's-pink-900',
    's-pink-950',
    's-rose-50',
    's-rose-100',
    's-rose-200',
    's-rose-300',
    's-rose-400',
    's-rose-500',
    's-rose-600',
    's-rose-700',
    's-rose-800',
    's-rose-900',
    's-rose-950',
    'e-inherit',
    'e-current',
    'e-transparent',
    'e-black',
    'e-white',
    'e-slate-50',
    'e-slate-100',
    'e-slate-200',
    'e-slate-300',
    'e-slate-400',
    'e-slate-500',
    'e-slate-600',
    'e-slate-700',
    'e-slate-800',
    'e-slate-900',
    'e-slate-950',
    'e-gray-50',
    'e-gray-100',
    'e-gray-200',
    'e-gray-300',
    'e-gray-400',
    'e-gray-500',
    'e-gray-600',
    'e-gray-700',
    'e-gray-800',
    'e-gray-900',
    'e-gray-950',
    'e-zinc-50',
    'e-zinc-100',
    'e-zinc-200',
    'e-zinc-300',
    'e-zinc-400',
    'e-zinc-500',
    'e-zinc-600',
    'e-zinc-700',
    'e-zinc-800',
    'e-zinc-900',
    'e-zinc-950',
    'e-neutral-50',
    'e-neutral-100',
    'e-neutral-200',
    'e-neutral-300',
    'e-neutral-400',
    'e-neutral-500',
    'e-neutral-600',
    'e-neutral-700',
    'e-neutral-800',
    'e-neutral-900',
    'e-neutral-950',
    'e-stone-50',
    'e-stone-100',
    'e-stone-200',
    'e-stone-300',
    'e-stone-400',
    'e-stone-500',
    'e-stone-600',
    'e-stone-700',
    'e-stone-800',
    'e-stone-900',
    'e-stone-950',
    'e-red-50',
    'e-red-100',
    'e-red-200',
    'e-red-300',
    'e-red-400',
    'e-red-500',
    'e-red-600',
    'e-red-700',
    'e-red-800',
    'e-red-900',
    'e-red-950',
    'e-orange-50',
    'e-orange-100',
    'e-orange-200',
    'e-orange-300',
    'e-orange-400',
    'e-orange-500',
    'e-orange-600',
    'e-orange-700',
    'e-orange-800',
    'e-orange-900',
    'e-orange-950',
    'e-amber-50',
    'e-amber-100',
    'e-amber-200',
    'e-amber-300',
    'e-amber-400',
    'e-amber-500',
    'e-amber-600',
    'e-amber-700',
    'e-amber-800',
    'e-amber-900',
    'e-amber-950',
    'e-yellow-50',
    'e-yellow-100',
    'e-yellow-200',
    'e-yellow-300',
    'e-yellow-400',
    'e-yellow-500',
    'e-yellow-600',
    'e-yellow-700',
    'e-yellow-800',
    'e-yellow-900',
    'e-yellow-950',
    'e-lime-50',
    'e-lime-100',
    'e-lime-200',
    'e-lime-300',
    'e-lime-400',
    'e-lime-500',
    'e-lime-600',
    'e-lime-700',
    'e-lime-800',
    'e-lime-900',
    'e-lime-950',
    'e-green-50',
    'e-green-100',
    'e-green-200',
    'e-green-300',
    'e-green-400',
    'e-green-500',
    'e-green-600',
    'e-green-700',
    'e-green-800',
    'e-green-900',
    'e-green-950',
    'e-emerald-50',
    'e-emerald-100',
    'e-emerald-200',
    'e-emerald-300',
    'e-emerald-400',
    'e-emerald-500',
    'e-emerald-600',
    'e-emerald-700',
    'e-emerald-800',
    'e-emerald-900',
    'e-emerald-950',
    'e-teal-50',
    'e-teal-100',
    'e-teal-200',
    'e-teal-300',
    'e-teal-400',
    'e-teal-500',
    'e-teal-600',
    'e-teal-700',
    'e-teal-800',
    'e-teal-900',
    'e-teal-950',
    'e-cyan-50',
    'e-cyan-100',
    'e-cyan-200',
    'e-cyan-300',
    'e-cyan-400',
    'e-cyan-500',
    'e-cyan-600',
    'e-cyan-700',
    'e-cyan-800',
    'e-cyan-900',
    'e-cyan-950',
    'e-sky-50',
    'e-sky-100',
    'e-sky-200',
    'e-sky-300',
    'e-sky-400',
    'e-sky-500',
    'e-sky-600',
    'e-sky-700',
    'e-sky-800',
    'e-sky-900',
    'e-sky-950',
    'e-blue-50',
    'e-blue-100',
    'e-blue-200',
    'e-blue-300',
    'e-blue-400',
    'e-blue-500',
    'e-blue-600',
    'e-blue-700',
    'e-blue-800',
    'e-blue-900',
    'e-blue-950',
    'e-indigo-50',
    'e-indigo-100',
    'e-indigo-200',
    'e-indigo-300',
    'e-indigo-400',
    'e-indigo-500',
    'e-indigo-600',
    'e-indigo-700',
    'e-indigo-800',
    'e-indigo-900',
    'e-indigo-950',
    'e-violet-50',
    'e-violet-100',
    'e-violet-200',
    'e-violet-300',
    'e-violet-400',
    'e-violet-500',
    'e-violet-600',
    'e-violet-700',
    'e-violet-800',
    'e-violet-900',
    'e-violet-950',
    'e-purple-50',
    'e-purple-100',
    'e-purple-200',
    'e-purple-300',
    'e-purple-400',
    'e-purple-500',
    'e-purple-600',
    'e-purple-700',
    'e-purple-800',
    'e-purple-900',
    'e-purple-950',
    'e-fuchsia-50',
    'e-fuchsia-100',
    'e-fuchsia-200',
    'e-fuchsia-300',
    'e-fuchsia-400',
    'e-fuchsia-500',
    'e-fuchsia-600',
    'e-fuchsia-700',
    'e-fuchsia-800',
    'e-fuchsia-900',
    'e-fuchsia-950',
    'e-pink-50',
    'e-pink-100',
    'e-pink-200',
    'e-pink-300',
    'e-pink-400',
    'e-pink-500',
    'e-pink-600',
    'e-pink-700',
    'e-pink-800',
    'e-pink-900',
    'e-pink-950',
    'e-rose-50',
    'e-rose-100',
    'e-rose-200',
    'e-rose-300',
    'e-rose-400',
    'e-rose-500',
    'e-rose-600',
    'e-rose-700',
    'e-rose-800',
    'e-rose-900',
    'e-rose-950',
    't-inherit',
    't-current',
    't-transparent',
    't-black',
    't-white',
    't-slate-50',
    't-slate-100',
    't-slate-200',
    't-slate-300',
    't-slate-400',
    't-slate-500',
    't-slate-600',
    't-slate-700',
    't-slate-800',
    't-slate-900',
    't-slate-950',
    't-gray-50',
    't-gray-100',
    't-gray-200',
    't-gray-300',
    't-gray-400',
    't-gray-500',
    't-gray-600',
    't-gray-700',
    't-gray-800',
    't-gray-900',
    't-gray-950',
    't-zinc-50',
    't-zinc-100',
    't-zinc-200',
    't-zinc-300',
    't-zinc-400',
    't-zinc-500',
    't-zinc-600',
    't-zinc-700',
    't-zinc-800',
    't-zinc-900',
    't-zinc-950',
    't-neutral-50',
    't-neutral-100',
    't-neutral-200',
    't-neutral-300',
    't-neutral-400',
    't-neutral-500',
    't-neutral-600',
    't-neutral-700',
    't-neutral-800',
    't-neutral-900',
    't-neutral-950',
    't-stone-50',
    't-stone-100',
    't-stone-200',
    't-stone-300',
    't-stone-400',
    't-stone-500',
    't-stone-600',
    't-stone-700',
    't-stone-800',
    't-stone-900',
    't-stone-950',
    't-red-50',
    't-red-100',
    't-red-200',
    't-red-300',
    't-red-400',
    't-red-500',
    't-red-600',
    't-red-700',
    't-red-800',
    't-red-900',
    't-red-950',
    't-orange-50',
    't-orange-100',
    't-orange-200',
    't-orange-300',
    't-orange-400',
    't-orange-500',
    't-orange-600',
    't-orange-700',
    't-orange-800',
    't-orange-900',
    't-orange-950',
    't-amber-50',
    't-amber-100',
    't-amber-200',
    't-amber-300',
    't-amber-400',
    't-amber-500',
    't-amber-600',
    't-amber-700',
    't-amber-800',
    't-amber-900',
    't-amber-950',
    't-yellow-50',
    't-yellow-100',
    't-yellow-200',
    't-yellow-300',
    't-yellow-400',
    't-yellow-500',
    't-yellow-600',
    't-yellow-700',
    't-yellow-800',
    't-yellow-900',
    't-yellow-950',
    't-lime-50',
    't-lime-100',
    't-lime-200',
    't-lime-300',
    't-lime-400',
    't-lime-500',
    't-lime-600',
    't-lime-700',
    't-lime-800',
    't-lime-900',
    't-lime-950',
    't-green-50',
    't-green-100',
    't-green-200',
    't-green-300',
    't-green-400',
    't-green-500',
    't-green-600',
    't-green-700',
    't-green-800',
    't-green-900',
    't-green-950',
    't-emerald-50',
    't-emerald-100',
    't-emerald-200',
    't-emerald-300',
    't-emerald-400',
    't-emerald-500',
    't-emerald-600',
    't-emerald-700',
    't-emerald-800',
    't-emerald-900',
    't-emerald-950',
    't-teal-50',
    't-teal-100',
    't-teal-200',
    't-teal-300',
    't-teal-400',
    't-teal-500',
    't-teal-600',
    't-teal-700',
    't-teal-800',
    't-teal-900',
    't-teal-950',
    't-cyan-50',
    't-cyan-100',
    't-cyan-200',
    't-cyan-300',
    't-cyan-400',
    't-cyan-500',
    't-cyan-600',
    't-cyan-700',
    't-cyan-800',
    't-cyan-900',
    't-cyan-950',
    't-sky-50',
    't-sky-100',
    't-sky-200',
    't-sky-300',
    't-sky-400',
    't-sky-500',
    't-sky-600',
    't-sky-700',
    't-sky-800',
    't-sky-900',
    't-sky-950',
    't-blue-50',
    't-blue-100',
    't-blue-200',
    't-blue-300',
    't-blue-400',
    't-blue-500',
    't-blue-600',
    't-blue-700',
    't-blue-800',
    't-blue-900',
    't-blue-950',
    't-indigo-50',
    't-indigo-100',
    't-indigo-200',
    't-indigo-300',
    't-indigo-400',
    't-indigo-500',
    't-indigo-600',
    't-indigo-700',
    't-indigo-800',
    't-indigo-900',
    't-indigo-950',
    't-violet-50',
    't-violet-100',
    't-violet-200',
    't-violet-300',
    't-violet-400',
    't-violet-500',
    't-violet-600',
    't-violet-700',
    't-violet-800',
    't-violet-900',
    't-violet-950',
    't-purple-50',
    't-purple-100',
    't-purple-200',
    't-purple-300',
    't-purple-400',
    't-purple-500',
    't-purple-600',
    't-purple-700',
    't-purple-800',
    't-purple-900',
    't-purple-950',
    't-fuchsia-50',
    't-fuchsia-100',
    't-fuchsia-200',
    't-fuchsia-300',
    't-fuchsia-400',
    't-fuchsia-500',
    't-fuchsia-600',
    't-fuchsia-700',
    't-fuchsia-800',
    't-fuchsia-900',
    't-fuchsia-950',
    't-pink-50',
    't-pink-100',
    't-pink-200',
    't-pink-300',
    't-pink-400',
    't-pink-500',
    't-pink-600',
    't-pink-700',
    't-pink-800',
    't-pink-900',
    't-pink-950',
    't-rose-50',
    't-rose-100',
    't-rose-200',
    't-rose-300',
    't-rose-400',
    't-rose-500',
    't-rose-600',
    't-rose-700',
    't-rose-800',
    't-rose-900',
    't-rose-950',
    'r-inherit',
    'r-current',
    'r-transparent',
    'r-black',
    'r-white',
    'r-slate-50',
    'r-slate-100',
    'r-slate-200',
    'r-slate-300',
    'r-slate-400',
    'r-slate-500',
    'r-slate-600',
    'r-slate-700',
    'r-slate-800',
    'r-slate-900',
    'r-slate-950',
    'r-gray-50',
    'r-gray-100',
    'r-gray-200',
    'r-gray-300',
    'r-gray-400',
    'r-gray-500',
    'r-gray-600',
    'r-gray-700',
    'r-gray-800',
    'r-gray-900',
    'r-gray-950',
    'r-zinc-50',
    'r-zinc-100',
    'r-zinc-200',
    'r-zinc-300',
    'r-zinc-400',
    'r-zinc-500',
    'r-zinc-600',
    'r-zinc-700',
    'r-zinc-800',
    'r-zinc-900',
    'r-zinc-950',
    'r-neutral-50',
    'r-neutral-100',
    'r-neutral-200',
    'r-neutral-300',
    'r-neutral-400',
    'r-neutral-500',
    'r-neutral-600',
    'r-neutral-700',
    'r-neutral-800',
    'r-neutral-900',
    'r-neutral-950',
    'r-stone-50',
    'r-stone-100',
    'r-stone-200',
    'r-stone-300',
    'r-stone-400',
    'r-stone-500',
    'r-stone-600',
    'r-stone-700',
    'r-stone-800',
    'r-stone-900',
    'r-stone-950',
    'r-red-50',
    'r-red-100',
    'r-red-200',
    'r-red-300',
    'r-red-400',
    'r-red-500',
    'r-red-600',
    'r-red-700',
    'r-red-800',
    'r-red-900',
    'r-red-950',
    'r-orange-50',
    'r-orange-100',
    'r-orange-200',
    'r-orange-300',
    'r-orange-400',
    'r-orange-500',
    'r-orange-600',
    'r-orange-700',
    'r-orange-800',
    'r-orange-900',
    'r-orange-950',
    'r-amber-50',
    'r-amber-100',
    'r-amber-200',
    'r-amber-300',
    'r-amber-400',
    'r-amber-500',
    'r-amber-600',
    'r-amber-700',
    'r-amber-800',
    'r-amber-900',
    'r-amber-950',
    'r-yellow-50',
    'r-yellow-100',
    'r-yellow-200',
    'r-yellow-300',
    'r-yellow-400',
    'r-yellow-500',
    'r-yellow-600',
    'r-yellow-700',
    'r-yellow-800',
    'r-yellow-900',
    'r-yellow-950',
    'r-lime-50',
    'r-lime-100',
    'r-lime-200',
    'r-lime-300',
    'r-lime-400',
    'r-lime-500',
    'r-lime-600',
    'r-lime-700',
    'r-lime-800',
    'r-lime-900',
    'r-lime-950',
    'r-green-50',
    'r-green-100',
    'r-green-200',
    'r-green-300',
    'r-green-400',
    'r-green-500',
    'r-green-600',
    'r-green-700',
    'r-green-800',
    'r-green-900',
    'r-green-950',
    'r-emerald-50',
    'r-emerald-100',
    'r-emerald-200',
    'r-emerald-300',
    'r-emerald-400',
    'r-emerald-500',
    'r-emerald-600',
    'r-emerald-700',
    'r-emerald-800',
    'r-emerald-900',
    'r-emerald-950',
    'r-teal-50',
    'r-teal-100',
    'r-teal-200',
    'r-teal-300',
    'r-teal-400',
    'r-teal-500',
    'r-teal-600',
    'r-teal-700',
    'r-teal-800',
    'r-teal-900',
    'r-teal-950',
    'r-cyan-50',
    'r-cyan-100',
    'r-cyan-200',
    'r-cyan-300',
    'r-cyan-400',
    'r-cyan-500',
    'r-cyan-600',
    'r-cyan-700',
    'r-cyan-800',
    'r-cyan-900',
    'r-cyan-950',
    'r-sky-50',
    'r-sky-100',
    'r-sky-200',
    'r-sky-300',
    'r-sky-400',
    'r-sky-500',
    'r-sky-600',
    'r-sky-700',
    'r-sky-800',
    'r-sky-900',
    'r-sky-950',
    'r-blue-50',
    'r-blue-100',
    'r-blue-200',
    'r-blue-300',
    'r-blue-400',
    'r-blue-500',
    'r-blue-600',
    'r-blue-700',
    'r-blue-800',
    'r-blue-900',
    'r-blue-950',
    'r-indigo-50',
    'r-indigo-100',
    'r-indigo-200',
    'r-indigo-300',
    'r-indigo-400',
    'r-indigo-500',
    'r-indigo-600',
    'r-indigo-700',
    'r-indigo-800',
    'r-indigo-900',
    'r-indigo-950',
    'r-violet-50',
    'r-violet-100',
    'r-violet-200',
    'r-violet-300',
    'r-violet-400',
    'r-violet-500',
    'r-violet-600',
    'r-violet-700',
    'r-violet-800',
    'r-violet-900',
    'r-violet-950',
    'r-purple-50',
    'r-purple-100',
    'r-purple-200',
    'r-purple-300',
    'r-purple-400',
    'r-purple-500',
    'r-purple-600',
    'r-purple-700',
    'r-purple-800',
    'r-purple-900',
    'r-purple-950',
    'r-fuchsia-50',
    'r-fuchsia-100',
    'r-fuchsia-200',
    'r-fuchsia-300',
    'r-fuchsia-400',
    'r-fuchsia-500',
    'r-fuchsia-600',
    'r-fuchsia-700',
    'r-fuchsia-800',
    'r-fuchsia-900',
    'r-fuchsia-950',
    'r-pink-50',
    'r-pink-100',
    'r-pink-200',
    'r-pink-300',
    'r-pink-400',
    'r-pink-500',
    'r-pink-600',
    'r-pink-700',
    'r-pink-800',
    'r-pink-900',
    'r-pink-950',
    'r-rose-50',
    'r-rose-100',
    'r-rose-200',
    'r-rose-300',
    'r-rose-400',
    'r-rose-500',
    'r-rose-600',
    'r-rose-700',
    'r-rose-800',
    'r-rose-900',
    'r-rose-950',
    'b-inherit',
    'b-current',
    'b-transparent',
    'b-black',
    'b-white',
    'b-slate-50',
    'b-slate-100',
    'b-slate-200',
    'b-slate-300',
    'b-slate-400',
    'b-slate-500',
    'b-slate-600',
    'b-slate-700',
    'b-slate-800',
    'b-slate-900',
    'b-slate-950',
    'b-gray-50',
    'b-gray-100',
    'b-gray-200',
    'b-gray-300',
    'b-gray-400',
    'b-gray-500',
    'b-gray-600',
    'b-gray-700',
    'b-gray-800',
    'b-gray-900',
    'b-gray-950',
    'b-zinc-50',
    'b-zinc-100',
    'b-zinc-200',
    'b-zinc-300',
    'b-zinc-400',
    'b-zinc-500',
    'b-zinc-600',
    'b-zinc-700',
    'b-zinc-800',
    'b-zinc-900',
    'b-zinc-950',
    'b-neutral-50',
    'b-neutral-100',
    'b-neutral-200',
    'b-neutral-300',
    'b-neutral-400',
    'b-neutral-500',
    'b-neutral-600',
    'b-neutral-700',
    'b-neutral-800',
    'b-neutral-900',
    'b-neutral-950',
    'b-stone-50',
    'b-stone-100',
    'b-stone-200',
    'b-stone-300',
    'b-stone-400',
    'b-stone-500',
    'b-stone-600',
    'b-stone-700',
    'b-stone-800',
    'b-stone-900',
    'b-stone-950',
    'b-red-50',
    'b-red-100',
    'b-red-200',
    'b-red-300',
    'b-red-400',
    'b-red-500',
    'b-red-600',
    'b-red-700',
    'b-red-800',
    'b-red-900',
    'b-red-950',
    'b-orange-50',
    'b-orange-100',
    'b-orange-200',
    'b-orange-300',
    'b-orange-400',
    'b-orange-500',
    'b-orange-600',
    'b-orange-700',
    'b-orange-800',
    'b-orange-900',
    'b-orange-950',
    'b-amber-50',
    'b-amber-100',
    'b-amber-200',
    'b-amber-300',
    'b-amber-400',
    'b-amber-500',
    'b-amber-600',
    'b-amber-700',
    'b-amber-800',
    'b-amber-900',
    'b-amber-950',
    'b-yellow-50',
    'b-yellow-100',
    'b-yellow-200',
    'b-yellow-300',
    'b-yellow-400',
    'b-yellow-500',
    'b-yellow-600',
    'b-yellow-700',
    'b-yellow-800',
    'b-yellow-900',
    'b-yellow-950',
    'b-lime-50',
    'b-lime-100',
    'b-lime-200',
    'b-lime-300',
    'b-lime-400',
    'b-lime-500',
    'b-lime-600',
    'b-lime-700',
    'b-lime-800',
    'b-lime-900',
    'b-lime-950',
    'b-green-50',
    'b-green-100',
    'b-green-200',
    'b-green-300',
    'b-green-400',
    'b-green-500',
    'b-green-600',
    'b-green-700',
    'b-green-800',
    'b-green-900',
    'b-green-950',
    'b-emerald-50',
    'b-emerald-100',
    'b-emerald-200',
    'b-emerald-300',
    'b-emerald-400',
    'b-emerald-500',
    'b-emerald-600',
    'b-emerald-700',
    'b-emerald-800',
    'b-emerald-900',
    'b-emerald-950',
    'b-teal-50',
    'b-teal-100',
    'b-teal-200',
    'b-teal-300',
    'b-teal-400',
    'b-teal-500',
    'b-teal-600',
    'b-teal-700',
    'b-teal-800',
    'b-teal-900',
    'b-teal-950',
    'b-cyan-50',
    'b-cyan-100',
    'b-cyan-200',
    'b-cyan-300',
    'b-cyan-400',
    'b-cyan-500',
    'b-cyan-600',
    'b-cyan-700',
    'b-cyan-800',
    'b-cyan-900',
    'b-cyan-950',
    'b-sky-50',
    'b-sky-100',
    'b-sky-200',
    'b-sky-300',
    'b-sky-400',
    'b-sky-500',
    'b-sky-600',
    'b-sky-700',
    'b-sky-800',
    'b-sky-900',
    'b-sky-950',
    'b-blue-50',
    'b-blue-100',
    'b-blue-200',
    'b-blue-300',
    'b-blue-400',
    'b-blue-500',
    'b-blue-600',
    'b-blue-700',
    'b-blue-800',
    'b-blue-900',
    'b-blue-950',
    'b-indigo-50',
    'b-indigo-100',
    'b-indigo-200',
    'b-indigo-300',
    'b-indigo-400',
    'b-indigo-500',
    'b-indigo-600',
    'b-indigo-700',
    'b-indigo-800',
    'b-indigo-900',
    'b-indigo-950',
    'b-violet-50',
    'b-violet-100',
    'b-violet-200',
    'b-violet-300',
    'b-violet-400',
    'b-violet-500',
    'b-violet-600',
    'b-violet-700',
    'b-violet-800',
    'b-violet-900',
    'b-violet-950',
    'b-purple-50',
    'b-purple-100',
    'b-purple-200',
    'b-purple-300',
    'b-purple-400',
    'b-purple-500',
    'b-purple-600',
    'b-purple-700',
    'b-purple-800',
    'b-purple-900',
    'b-purple-950',
    'b-fuchsia-50',
    'b-fuchsia-100',
    'b-fuchsia-200',
    'b-fuchsia-300',
    'b-fuchsia-400',
    'b-fuchsia-500',
    'b-fuchsia-600',
    'b-fuchsia-700',
    'b-fuchsia-800',
    'b-fuchsia-900',
    'b-fuchsia-950',
    'b-pink-50',
    'b-pink-100',
    'b-pink-200',
    'b-pink-300',
    'b-pink-400',
    'b-pink-500',
    'b-pink-600',
    'b-pink-700',
    'b-pink-800',
    'b-pink-900',
    'b-pink-950',
    'b-rose-50',
    'b-rose-100',
    'b-rose-200',
    'b-rose-300',
    'b-rose-400',
    'b-rose-500',
    'b-rose-600',
    'b-rose-700',
    'b-rose-800',
    'b-rose-900',
    'b-rose-950',
    'l-inherit',
    'l-current',
    'l-transparent',
    'l-black',
    'l-white',
    'l-slate-50',
    'l-slate-100',
    'l-slate-200',
    'l-slate-300',
    'l-slate-400',
    'l-slate-500',
    'l-slate-600',
    'l-slate-700',
    'l-slate-800',
    'l-slate-900',
    'l-slate-950',
    'l-gray-50',
    'l-gray-100',
    'l-gray-200',
    'l-gray-300',
    'l-gray-400',
    'l-gray-500',
    'l-gray-600',
    'l-gray-700',
    'l-gray-800',
    'l-gray-900',
    'l-gray-950',
    'l-zinc-50',
    'l-zinc-100',
    'l-zinc-200',
    'l-zinc-300',
    'l-zinc-400',
    'l-zinc-500',
    'l-zinc-600',
    'l-zinc-700',
    'l-zinc-800',
    'l-zinc-900',
    'l-zinc-950',
    'l-neutral-50',
    'l-neutral-100',
    'l-neutral-200',
    'l-neutral-300',
    'l-neutral-400',
    'l-neutral-500',
    'l-neutral-600',
    'l-neutral-700',
    'l-neutral-800',
    'l-neutral-900',
    'l-neutral-950',
    'l-stone-50',
    'l-stone-100',
    'l-stone-200',
    'l-stone-300',
    'l-stone-400',
    'l-stone-500',
    'l-stone-600',
    'l-stone-700',
    'l-stone-800',
    'l-stone-900',
    'l-stone-950',
    'l-red-50',
    'l-red-100',
    'l-red-200',
    'l-red-300',
    'l-red-400',
    'l-red-500',
    'l-red-600',
    'l-red-700',
    'l-red-800',
    'l-red-900',
    'l-red-950',
    'l-orange-50',
    'l-orange-100',
    'l-orange-200',
    'l-orange-300',
    'l-orange-400',
    'l-orange-500',
    'l-orange-600',
    'l-orange-700',
    'l-orange-800',
    'l-orange-900',
    'l-orange-950',
    'l-amber-50',
    'l-amber-100',
    'l-amber-200',
    'l-amber-300',
    'l-amber-400',
    'l-amber-500',
    'l-amber-600',
    'l-amber-700',
    'l-amber-800',
    'l-amber-900',
    'l-amber-950',
    'l-yellow-50',
    'l-yellow-100',
    'l-yellow-200',
    'l-yellow-300',
    'l-yellow-400',
    'l-yellow-500',
    'l-yellow-600',
    'l-yellow-700',
    'l-yellow-800',
    'l-yellow-900',
    'l-yellow-950',
    'l-lime-50',
    'l-lime-100',
    'l-lime-200',
    'l-lime-300',
    'l-lime-400',
    'l-lime-500',
    'l-lime-600',
    'l-lime-700',
    'l-lime-800',
    'l-lime-900',
    'l-lime-950',
    'l-green-50',
    'l-green-100',
    'l-green-200',
    'l-green-300',
    'l-green-400',
    'l-green-500',
    'l-green-600',
    'l-green-700',
    'l-green-800',
    'l-green-900',
    'l-green-950',
    'l-emerald-50',
    'l-emerald-100',
    'l-emerald-200',
    'l-emerald-300',
    'l-emerald-400',
    'l-emerald-500',
    'l-emerald-600',
    'l-emerald-700',
    'l-emerald-800',
    'l-emerald-900',
    'l-emerald-950',
    'l-teal-50',
    'l-teal-100',
    'l-teal-200',
    'l-teal-300',
    'l-teal-400',
    'l-teal-500',
    'l-teal-600',
    'l-teal-700',
    'l-teal-800',
    'l-teal-900',
    'l-teal-950',
    'l-cyan-50',
    'l-cyan-100',
    'l-cyan-200',
    'l-cyan-300',
    'l-cyan-400',
    'l-cyan-500',
    'l-cyan-600',
    'l-cyan-700',
    'l-cyan-800',
    'l-cyan-900',
    'l-cyan-950',
    'l-sky-50',
    'l-sky-100',
    'l-sky-200',
    'l-sky-300',
    'l-sky-400',
    'l-sky-500',
    'l-sky-600',
    'l-sky-700',
    'l-sky-800',
    'l-sky-900',
    'l-sky-950',
    'l-blue-50',
    'l-blue-100',
    'l-blue-200',
    'l-blue-300',
    'l-blue-400',
    'l-blue-500',
    'l-blue-600',
    'l-blue-700',
    'l-blue-800',
    'l-blue-900',
    'l-blue-950',
    'l-indigo-50',
    'l-indigo-100',
    'l-indigo-200',
    'l-indigo-300',
    'l-indigo-400',
    'l-indigo-500',
    'l-indigo-600',
    'l-indigo-700',
    'l-indigo-800',
    'l-indigo-900',
    'l-indigo-950',
    'l-violet-50',
    'l-violet-100',
    'l-violet-200',
    'l-violet-300',
    'l-violet-400',
    'l-violet-500',
    'l-violet-600',
    'l-violet-700',
    'l-violet-800',
    'l-violet-900',
    'l-violet-950',
    'l-purple-50',
    'l-purple-100',
    'l-purple-200',
    'l-purple-300',
    'l-purple-400',
    'l-purple-500',
    'l-purple-600',
    'l-purple-700',
    'l-purple-800',
    'l-purple-900',
    'l-purple-950',
    'l-fuchsia-50',
    'l-fuchsia-100',
    'l-fuchsia-200',
    'l-fuchsia-300',
    'l-fuchsia-400',
    'l-fuchsia-500',
    'l-fuchsia-600',
    'l-fuchsia-700',
    'l-fuchsia-800',
    'l-fuchsia-900',
    'l-fuchsia-950',
    'l-pink-50',
    'l-pink-100',
    'l-pink-200',
    'l-pink-300',
    'l-pink-400',
    'l-pink-500',
    'l-pink-600',
    'l-pink-700',
    'l-pink-800',
    'l-pink-900',
    'l-pink-950',
    'l-rose-50',
    'l-rose-100',
    'l-rose-200',
    'l-rose-300',
    'l-rose-400',
    'l-rose-500',
    'l-rose-600',
    'l-rose-700',
    'l-rose-800',
    'l-rose-900',
    'l-rose-950',
]
